%% Parameter settings
% Save results
para.ResultName='ResultsF2F_massiveMIMO.mat';
para.SaveResults=0;       % 1: save results 2: do not save results

% System setting
para.M_T=2;             % number of transmit antennas
para.M_R=2;             % number of receive antennas
para.fc=2600000000;      % carrier frequency
para.c=300000000;        % speed of light
para.lambda=para.c/para.fc;        % wavelength
para.K_ricean_db=-inf;      % Ricean factor in dB
para.K_ricean_lin=10^(para.K_ricean_db/10);     % Ricean factor in linear
para.rand_seed=48;                    % random seed setting for rand: default:LOS 48 NLOS 48
rand('seed',para.rand_seed);         % set random seed
para.randn_seed=para.rand_seed+20;                   % random seed setting for randn
randn('seed',para.randn_seed);       % set random seed

para.D=200;              % distance between the transmitter and receiver

% transmit antenna settings
para.nu_A_T=pi/3;            % Azimuth angle of Tx antenna array
para.nu_E_T=pi/4;               % Elevation angle of Tx antenna array
% receive antenna settings
para.nu_A_R=pi/4;            % Azimuth angle of Rx antenna array
para.nu_E_R=pi/4;               % Elevation angle of Rx antenna array

para.theta_v_R= 2*pi*(rand-0.5);           % Azimuth angle of the movement of the Rx array
para.xi_v_R=pi*(rand-0.5);               % Elevation angle of the movement of the Rx array

para.theta_v_T=2*pi*(rand-0.5);           % Azimuth angle of the movement of the Tx array
para.xi_v_T=pi*(rand-0.5);               % Elevation angle of the movement of the Tx array

para.delta_tx=0.5;                   % antenna space/wavelength for tx
para.delta_rx=0.5;                   % antenna space/wavelength for rx
% space birth death process settings
% para.space_birth_death_process=0;    % space birth death process: 0-disabled, 1-enabled
if 0.0001>para.K_ricean_lin          % NLOS case
    para.lambdaG=80;                 % generation rate
    para.lambdaR=4;                  % recombination rate
    para.DS_miu=-6.63;               % delay spread mean in dB
    para.DS_sigma=0.32;              % delay spread variance in dB
    para.DS_r=2.3;                   % delay scaling parameter
    %     AoA_mean=-30.2;                 % mean AoA from COST2100 doc
    para.AAoA_variance=66;                % variance AAoA from COST2100 doc
    para.AAoD_variance=30.6;                % variance AAoD from COST2100 doc 30.6
    para.EAoA_variance=10.2;                % variance EAoA from COST2100 doc
    para.EAoD_variance=6.4;                % variance AAoD from COST2100 doc
    para.d_Rx_min=10;                      % dRx_min
    para.d_Rx_mean=15;                     % dRx_mean
    para.d_Tx_min=10;                      % dTx_min
    para.d_Tx_mean=20;                     % dTx_mean
    para.tau_tilder_mean=74.8*10^-9;       % delay tilder mean
    para.tau_tilder_min=14*10^-9;          % delay tilder min

else % LOS case
    para.lambdaG=32;                 % generation rate
    para.lambdaR=4;                  % recombination rate
    para.DS_miu=-7.39;               % delay spread mean in dB
    para.DS_sigma=0.63;              % delay spread variance in dB
    para.DS_r=2.5;                   % delay scaling parameter
    %     AoA_mean=-7.6;                 % mean AoA from COST2100 doc
    para.AAoA_variance=38.8;                % variance AoA from COST2100 doc
    para.AAoD_variance=47;                % variance AAoD from COST2100 doc
    para.EAoA_variance=38.2;                % variance EAoA from COST2100 doc
    para.EAoD_variance=23.5;                % variance AAoD from COST2100 doc
    para.d_Rx_min=10;                      % dRx_min
    para.d_Rx_mean=15;                     % dRx_mean
    para.d_Tx_min=10;                      % dTx_min
    para.d_Tx_mean=20;                     % dTx_mean
    para.tau_tilder_mean=44.1*10^-9;       % delay tilder mean
    para.tau_tilder_min=27.3*10^-9;          % delay tilder min
end
para.ds_sigma=10^(para.DS_sigma*randn(1,1)+para.DS_miu);

% sub path settings
para.mean_num_subpath=15;            % mean number of subpaths within a cluster
para.mean_delay_subpath=15*10^-9;            % mean delay of subpaths within a cluster
para.angular_variance_subpath=1;%     % in degrees

% correlation distance settings
para.A_Corr_distance=30;              % antenna correlation distance
para.Corr_distance=100;                % correlation distance% % time birth death process settings
para.T_Corr_distance=7;               % time correlation distance in second


para.T0=4.001;                           % intial time
para.Tend=4.05;                         % end time
para.dT=0.001;                     % delta time
para.TimeLine=para.T0:para.dT:para.Tend;
para.T_length=length(para.TimeLine);      % length of time axis
para.P_F=0.3;                        % percentage of fluctuating MPCs
para.v_F=0;                        % mean cluster velocity default: 0.5
para.v_c=0;                        % cluster velocity default: 0.5
para.v_R=0;              % speed of velocity of receiver default: 3
para.v_T=0;              % speed of velocity of transmitter default: 3

% 
para.Per_cluster_shadowing=3;        % per cluster shadowing std in dB

% % von Mises setting
% para.vonMises_mean_theta=pi/6;
% para.vonMises_k=5;
% Polarization setting
para.Polarization_Tx=0;
para.Polarization_Rx=1;
para.Polar_kappa=-8;      % polarization coefficient in dB
para.Polar_kappa_linear=10^(para.Polar_kappa/10); % polarization coefficient linear
para.FieldPatternTx=@OmniFieldPattern;    % @DipoleFieldPattern, @OmniFieldPattern
para.FieldPatternRx=@OmniFieldPattern;    % @DipoleFieldPattern, @OmniFieldPattern
para.Tx_Rot_x=pi/15;                % rotation of Tx with respect to x
para.Tx_Rot_y=pi/15;                % rotation of Tx with respect to y
para.Tx_Rot_z=pi/15;                % rotation of Tx with respect to z
para.Rx_Rot_x=pi/15;                % rotation of Rx with respect to x
para.Rx_Rot_y=pi/15;                % rotation of Rx with respect to y
para.Rx_Rot_z=pi/15;                % rotation of Rx with respect to z